---
name: New feature
about: Submit a PR to help us improve
title: "[New feature]"
labels: ''
assignees: ''

---


**Describe what feature you made**
A clear and concise description of the feature you made. If it is related to any issue, provide the issue number will be very appreciated.

**Example/Use case**
If there is an example or use case will be very usful to others. It might be a short code snippet to demonstrate how to use this new feature.

**Checklist**

- [ ] I've already read the [contributing guide](../../CONTRIBUTING.md).
- [ ] I've run all tests and make sure all exists test cases are passed.
- [ ] I've make sure this PR works with `Sanic-18.12` and `Python-3.5`.
